@@ -1,8 +1,8 @@
-from abc import ABCMeta
-from abc import abstractmethod
-from typing import Any
+from abc import ABCMeta, abstractmethod, abstractproperty
+from typing import Any, Union
 
 from .storage_item import StorageItem
+from .storage_frame import StorageFrame
 from .operation_result import OperationResult
 
 
@@ -13,24 +13,28 @@ class StorageORM(metaclass=ABCMeta):
     def __init__(
         self,
         client: Any = None,
-        host: str = None,
+        host: Union[str, None] = None,
         port: int = 6379,
         db: int = 0,
     ) -> None:
         raise NotImplementedError
 
     @abstractmethod
-    async def save(self, item: StorageItem) -> OperationResult:
+    async def save(self, item) -> OperationResult:
         raise NotImplementedError
 
     @abstractmethod
-    async def bulk_create(self, items: list[StorageItem]) -> OperationResult:
+    async def bulk_create(self, items: list) -> OperationResult:
         raise NotImplementedError
 
     @abstractmethod
-    async def bulk_delete(self, items: list[StorageItem]) -> OperationResult:
+    async def bulk_delete(self, items: list) -> OperationResult:
         raise NotImplementedError
 
     @abstractmethod
-    async def delete(self, item: StorageItem) -> OperationResult:
+    async def delete(self, item) -> OperationResult:
+        raise NotImplementedError
+
+    @abstractproperty
+    def frame(self) -> StorageFrame:
         raise NotImplementedError
